"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const ad_record_1 = require("../records/ad.record");
const db_1 = require("../utils/db");
const defaultObj = {
    name: '[Test] Name',
    description: 'Example description',
    price: 200,
    url: "https://onet.pl",
    latitude: 33,
    longitude: 24
};
afterAll(() => __awaiter(void 0, void 0, void 0, function* () {
    yield db_1.pool.end();
}));
test('AdRecord returns data from database of one entry.', () => __awaiter(void 0, void 0, void 0, function* () {
    const ad = yield ad_record_1.AdRecord.getOne('e00814d7-c93c-48f0-ac17-3576787dc3b1');
    expect(ad).toBeDefined();
    expect(ad.id).toBe('e00814d7-c93c-48f0-ac17-3576787dc3b1');
    expect(ad.name).toBe('Testowa');
    expect(ad.latitude).toBe(50.2335986);
}));
test('AdRecord.getOne returns null from database for unexisting entry.', () => __awaiter(void 0, void 0, void 0, function* () {
    const ad = yield ad_record_1.AdRecord.getOne('xxxxxxx');
    expect(ad).toBeNull();
}));
test('AdRecord.findAll returns array of found entries.', () => __awaiter(void 0, void 0, void 0, function* () {
    const ads = yield ad_record_1.AdRecord.findAll('');
    expect(ads).not.toEqual([]);
    expect(ads[0].id).toBeDefined();
}));
test('AdRecord.findAll returns array of found entries when searching for "a".', () => __awaiter(void 0, void 0, void 0, function* () {
    const ads = yield ad_record_1.AdRecord.findAll('a');
    expect(ads).not.toEqual([]);
    expect(ads[0].id).toBeDefined();
}));
test('AdRecord.findAll returns empty array when searching for something that not exists.', () => __awaiter(void 0, void 0, void 0, function* () {
    const ads = yield ad_record_1.AdRecord.findAll('xxxxxxxxxxxx');
    expect(ads).toEqual([]);
}));
test('AdRecord.findAll returns small amount of data.', () => __awaiter(void 0, void 0, void 0, function* () {
    const ads = yield ad_record_1.AdRecord.findAll('');
    expect(ads[0].id).toBeDefined();
    expect(ads[0].latitude).toBeDefined();
    expect(ads[0].longitude).toBeDefined();
    // as AdEntity by "oszukać" TypeScript by tego nie pilnował (SimpleAdEntity nie ma takich kluczy)
    expect(ads[0].name).toBeUndefined();
    expect(ads[0].description).toBeUndefined();
    expect(ads[0].price).toBeUndefined();
    expect(ads[0].url).toBeUndefined();
}));
test('AdRecord.insert returns UUID.', () => __awaiter(void 0, void 0, void 0, function* () {
    const ad = new ad_record_1.AdRecord(defaultObj);
    yield ad.insert();
    expect(ad.id).toBeDefined();
    expect(typeof ad.id).toBe('string');
}));
test('AdRecord.insert inserts data to database.', () => __awaiter(void 0, void 0, void 0, function* () {
    const ad = new ad_record_1.AdRecord(defaultObj);
    yield ad.insert();
    const foundAd = yield ad_record_1.AdRecord.getOne(ad.id);
    expect(foundAd).toBeDefined();
    expect(foundAd).not.toBeNull();
    expect(foundAd.id).toBe(ad.id);
}));
//# sourceMappingURL=ad.test.js.map