import {AdRecord} from "../records/ad.record";
import {ValidationError} from "../utils/errors";

const defaultObj = new AdRecord({
    name: 'Test Name',
    description: 'Example description',
    price: 100,
    url: "https://google.com",
    latitude: 52,
    longitude: 44
})

test('Can build AdRecord', () => {
    const ad = new AdRecord(defaultObj);

    expect(ad.name).toBe('Test Name');
    expect(ad.description).toBe('Example description');
    expect(ad.url).toBe('https://google.com');
    expect(ad.price).toBeDefined();
})

test('Validates invalid price', () => {
    expect(() => new AdRecord({
        ...defaultObj,
        price: -20,
    })).toThrow('Cena nie może być niższa niż 0 i wyższa niż 9 999 999.');

    expect(() => new AdRecord({
        ...defaultObj,
        price: 2229999999,
    })).toThrow('Cena nie może być niższa niż 0 i wyższa niż 9 999 999.');
});

test('Validates invalid name', () => {
    expect(() => new AdRecord({
        ...defaultObj,
        name: "",
    })).toThrow('Nazwa ogłoszenia nie może być pusta lub przekraczać 100 znaków.');

    expect(() => new AdRecord({
        ...defaultObj,
        name: 'Lorem ipsum dolor sit amet, consectetur adipiscing elit interdum hendrerit ex vitae sodales. Lorem ipsum dolor sit am.',
    })).toThrow('Nazwa ogłoszenia nie może być pusta lub przekraczać 100 znaków.');
})

// @TODO check all the validations
