import {AdRecord} from "../records/ad.record";
import {pool} from "../utils/db";
import {AdEntity} from "../types";

const defaultObj = {
    name: '[Test] Name',
    description: 'Example description',
    price: 200,
    url: "https://onet.pl",
    latitude: 33,
    longitude: 24
}

afterAll(async () => {
    await pool.end();
})

test('AdRecord returns data from database of one entry.', async () => {
    const ad = await AdRecord.getOne('e00814d7-c93c-48f0-ac17-3576787dc3b1');
    expect(ad).toBeDefined();
    expect(ad.id).toBe('e00814d7-c93c-48f0-ac17-3576787dc3b1');
    expect(ad.name).toBe('Testowa');
    expect(ad.latitude).toBe(50.2335986);
})

test('AdRecord.getOne returns null from database for unexisting entry.', async () => {
    const ad = await AdRecord.getOne('xxxxxxx');
    expect(ad).toBeNull();
});

test('AdRecord.findAll returns array of found entries.', async () => {
    const ads = await AdRecord.findAll('');
    expect(ads).not.toEqual([]);
    expect(ads[0].id).toBeDefined();
});

test('AdRecord.findAll returns array of found entries when searching for "a".', async () => {
    const ads = await AdRecord.findAll('a');
    expect(ads).not.toEqual([]);
    expect(ads[0].id).toBeDefined();
});

test('AdRecord.findAll returns empty array when searching for something that not exists.', async () => {
    const ads = await AdRecord.findAll('xxxxxxxxxxxx');
    expect(ads).toEqual([]);
});

test('AdRecord.findAll returns small amount of data.', async () => {
    const ads = await AdRecord.findAll('');
    expect(ads[0].id).toBeDefined();
    expect(ads[0].latitude).toBeDefined();
    expect(ads[0].longitude).toBeDefined();
    // as AdEntity by "oszukać" TypeScript by tego nie pilnował (SimpleAdEntity nie ma takich kluczy)
    expect((ads[0] as AdEntity).name).toBeUndefined();
    expect((ads[0] as AdEntity).description).toBeUndefined();
    expect((ads[0] as AdEntity).price).toBeUndefined();
    expect((ads[0] as AdEntity).url).toBeUndefined();
});

test('AdRecord.insert returns UUID.', async () => {
    const ad = new AdRecord(defaultObj)
    await ad.insert();

    expect(ad.id).toBeDefined();
    expect(typeof ad.id).toBe('string');
});

test('AdRecord.insert inserts data to database.', async () => {
    const ad = new AdRecord(defaultObj)
    await ad.insert();

    const foundAd = await AdRecord.getOne(ad.id);

    expect(foundAd).toBeDefined();
    expect(foundAd).not.toBeNull();
    expect(foundAd.id).toBe(ad.id);
});

