"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.SpotRecord = void 0;
const uuid_1 = require("uuid");
const errors_1 = require("../utils/errors");
const db_1 = require("../utils/db");
class SpotRecord {
    constructor(obj) {
        const { 
        // eslint-disable-next-line max-len
        id, name, description, image, latitude, longitude, siteUrl, facebookUrl, youtubeUrl, instagramUrl, spotAddress, } = obj;
        if (!name || name.length > 100) {
            throw new errors_1.ValidationError('Nazwa miejscówki nie może być pusta, albo dłuższa niż 100 znaków.');
        }
        if (description && description.length > 1000) {
            throw new errors_1.ValidationError('Opis miejscówki nie może przekraczać 1000 znaków.');
        }
        if (spotAddress && spotAddress.length > 150) {
            throw new errors_1.ValidationError('Adres miejscówki nie może przekraczać 150 znaków.');
        }
        // @TODO check if url is valid
        // eslint-disable-next-line max-len
        if ((siteUrl && siteUrl.length) > 100 || (facebookUrl && facebookUrl.length) > 100 || (youtubeUrl && youtubeUrl.length) > 100 || (instagramUrl && instagramUrl.length) > 100) {
            throw new errors_1.ValidationError('Link do strony www lub social media użytkownika nie może być dłuższy niż 100 znaków.');
        }
        if ((typeof latitude !== 'number') || (typeof longitude !== 'number')) {
            throw new errors_1.ValidationError('Nie można zlokalizować miejscówki.');
        }
        this.id = id;
        this.name = name;
        this.description = description;
        this.image = image;
        this.latitude = latitude;
        this.longitude = longitude;
        this.siteUrl = siteUrl;
        this.facebookUrl = facebookUrl;
        this.youtubeUrl = youtubeUrl;
        this.instagramUrl = instagramUrl;
        this.spotAddress = spotAddress;
    }
    static getOne(id) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute('SELECT * FROM `spots` WHERE `id` = :id', {
                id,
            });
            return results.length === 0 ? null : new SpotRecord(results[0]);
        });
    }
    static getAll(name) {
        return __awaiter(this, void 0, void 0, function* () {
            const filteredName = name.replace(/[^a-zA-Z0-9 ęóąśłżźćń]/g, '');
            const [results] = yield db_1.pool.execute('SELECT * FROM `spots` WHERE `spotAddress` LIKE :search', {
                search: `%${filteredName}%`,
            });
            return results.map((result) => {
                const { id, latitude, longitude } = result;
                return {
                    id, latitude, longitude,
                };
            });
        });
    }
    insert() {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.id) {
                this.id = (0, uuid_1.v4)();
            }
            else {
                throw new Error('Cannot insert something that is already inserted.');
            }
            const filteredSpotAddress = this.spotAddress.replace(/[^a-zA-Z0-9 ęóąśłżźćń]/g, '');
            yield db_1.pool.execute('INSERT INTO `spots`(`id`, `name`, `description`, `image`, `latitude`, `longitude`,  `siteUrl`, `facebookUrl`, `youtubeUrl`, `instagramUrl`, `spotAddress`) VALUES(:id, :name, :description, :image, :latitude, :longitude, :siteUrl, :facebookUrl, :youtubeUrl, :instagramUrl, :spotAddress)', Object.assign(Object.assign({}, this), { spotAddress: filteredSpotAddress }));
        });
    }
}
exports.SpotRecord = SpotRecord;
//# sourceMappingURL=spot.record.js.map