"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.spotRouter = void 0;
const express_1 = require("express");
const multer_1 = __importDefault(require("multer"));
const spot_record_1 = require("../records/spot.record");
exports.spotRouter = (0, express_1.Router)();
const fileStorageEngine = multer_1.default.diskStorage({
    destination: (req, file, cb) => {
        cb(null, './images');
    },
    filename: (req, file, cb) => {
        cb(null, `${Date.now()}-${file.originalname}`);
    },
});
const fileFilter = (req, file, cb) => {
    if (file.mimetype === 'image/jpeg' || file.mimetype === 'image/jpg' || file.mimetype === 'image/png') {
        cb(null, true);
    }
    else {
        cb(null, false);
    }
};
const upload = (0, multer_1.default)({
    storage: fileStorageEngine,
    limits: {
        fileSize: 1024 * 1024 * 10, // limit 10MB
    },
    fileFilter,
});
exports.spotRouter
    .get('/search/:spotAddress?', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    var _a;
    const spots = yield spot_record_1.SpotRecord.getAll((_a = req.params.spotAddress) !== null && _a !== void 0 ? _a : '');
    res.json(spots);
}))
    .get('/:id', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    const spot = yield spot_record_1.SpotRecord.getOne(req.params.id);
    res.json(spot);
}))
    // .post('/', async (req, res) => {
    //     const spot = new SpotRecord(req.body);
    //     await spot.insert();
    //     res.json(spot);
    // });
    .post('/', upload.single('image'), (req, res, next) => __awaiter(void 0, void 0, void 0, function* () {
    // console.log(req.file);
    const spot = new spot_record_1.SpotRecord(req.body);
    yield spot.insert();
    res.json(spot);
}));
//# sourceMappingURL=spot.router.js.map