"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const spot_record_1 = require("../records/spot.record");
const db_1 = require("../utils/db");
/* eslint-disable no-undef */
const defaultSpotObj = {
    name: '[TEST] Example Name',
    description: 'This is the best place in city.',
    image: 'example.jpg',
    siteUrl: 'https://google.com/',
    facebookUrl: 'https://facebook.com/',
    youtubeUrl: 'https://youtube.com/',
    instagramUrl: 'https://instagram.com/',
    latitude: 50.264279,
    longitude: 19.023651,
    spotAddress: 'rondo Gen. Jerzego Ziętka, Katowice',
};
afterAll(() => __awaiter(void 0, void 0, void 0, function* () {
    yield db_1.pool.end();
}));
test('SpotRecord returns data from database for one entry.', () => __awaiter(void 0, void 0, void 0, function* () {
    const spot = yield spot_record_1.SpotRecord.getOne('exampleId');
    expect(spot).toBeDefined();
    expect(spot.id).toEqual('exampleId');
    expect(spot.name).toEqual('[TEST] Rynek');
    expect(spot.description).toEqual('katowicki rynek');
    expect(spot.latitude).toEqual(50.259474);
    expect(spot.longitude).toEqual(19.022254);
    expect(spot.siteUrl).toEqual('https://katowice.eu');
    expect(spot.facebookUrl).toBeNull();
    expect(spot.youtubeUrl).toBeNull();
    expect(spot.instagramUrl).toBeNull();
}));
test('SpotRecord.getOne returns null from database for unexisting entry.', () => __awaiter(void 0, void 0, void 0, function* () {
    const spot = yield spot_record_1.SpotRecord.getOne('noId');
    expect(spot).toBeNull();
}));
test('SpotRecord.getAll returns array of found entries.', () => __awaiter(void 0, void 0, void 0, function* () {
    const spots = yield spot_record_1.SpotRecord.getAll('');
    expect(spots).not.toEqual([]);
    expect(spots[0]).toBeDefined();
}));
test('SpotRecord.getAll returns an empty array when searching for something that not exists.', () => __awaiter(void 0, void 0, void 0, function* () {
    const spots = yield spot_record_1.SpotRecord.getAll('qwertyuiop asdfghjkl zaq12wsx');
    expect(spots).toEqual([]);
}));
test('SpotRecord.getAll returns not all data but only: id, latitude and longitude', () => __awaiter(void 0, void 0, void 0, function* () {
    const spots = yield spot_record_1.SpotRecord.getAll('');
    expect(spots[0].id).toBeDefined();
    expect(spots[0].latitude).toBeDefined();
    expect(spots[0].longitude).toBeDefined();
    expect(spots[0].name).toBeUndefined();
    expect(spots[0].description).toBeUndefined();
    expect(spots[0].image).toBeUndefined();
    expect(spots[0].siteUrl).toBeUndefined();
    expect(spots[0].facebookUrl).toBeUndefined();
    expect(spots[0].youtubeUrl).toBeUndefined();
    expect(spots[0].instagramUrl).toBeUndefined();
}));
test('SpotRecord.getAll returns array of found entries when searching for "Rynek 1".', () => __awaiter(void 0, void 0, void 0, function* () {
    const spots = yield spot_record_1.SpotRecord.getAll('Rynek 1');
    expect(spots).not.toEqual([]);
    expect(spots[0].id).toBeDefined();
}));
test('SpotRecord.insert returns new UUID.', () => __awaiter(void 0, void 0, void 0, function* () {
    const spot = new spot_record_1.SpotRecord(defaultSpotObj);
    yield spot.insert();
    expect(spot.id).toBeDefined();
    expect(spot.id.length).toEqual(36);
    expect(typeof spot.id).toBe('string');
}));
test('SpotRecord.insert inserts data to database.', () => __awaiter(void 0, void 0, void 0, function* () {
    const spot = new spot_record_1.SpotRecord(defaultSpotObj);
    yield spot.insert();
    const foundSpot = yield spot_record_1.SpotRecord.getOne(spot.id);
    expect(foundSpot).toBeDefined();
    expect(foundSpot).not.toBeNull();
    expect(foundSpot.id).toBe(spot.id);
    expect(foundSpot.name).toEqual(spot.name);
    expect(foundSpot.description).toEqual(spot.description);
    expect(foundSpot.image).toEqual(spot.image);
    expect(foundSpot.siteUrl).toEqual(spot.siteUrl);
    expect(foundSpot.facebookUrl).toEqual(spot.facebookUrl);
    expect(foundSpot.youtubeUrl).toEqual(spot.youtubeUrl);
    expect(foundSpot.instagramUrl).toEqual(spot.instagramUrl);
    expect(foundSpot.latitude).toEqual(spot.latitude);
    expect(foundSpot.longitude).toEqual(spot.longitude);
}));
/* eslint-enables no-undef */
//# sourceMappingURL=spot.test.js.map